edgar.schema

Malli schemas and validation helpers for the edgarjure public API.

Usage (in edgar.api): (schema/validate! ::filings-args {:ticker-or-cik toc :form form ...})

All public validate! calls throw ex-info with :type ::invalid-args on failure. The error message includes the human-readable Malli explanation.

Malli schemas and validation helpers for the edgarjure public API.

Usage (in edgar.api):
  (schema/validate! ::filings-args {:ticker-or-cik toc :form form ...})

All public validate! calls throw ex-info with :type ::invalid-args on failure.
The error message includes the human-readable Malli explanation.
raw docstring

AccessionNumberclj

source

ConceptArgclj

source

FactsArgsclj

source

FilingArgsclj

source

FilingByAccessionArgsclj

source

FilingsArgsclj

source

FormTypeclj

source

FrameArgsclj

source

FrameStrclj

source

InitArgsclj

source

ISODateclj

source

NonBlankStringclj

source

PanelArgsclj

source

PositiveIntclj

source

SearchArgsclj

source

SearchFilingsArgsclj

source

ShapeKwclj

source

StatementArgsclj

source

TablesArgsclj

source

TaxonomyStrclj

source

TickerOrCIKclj

source

validate!clj

(validate! schema args-map)

Validate args-map against schema. Throws ex-info with :type ::invalid-args and a human-readable :message on failure. Returns nil on success.

Validate args-map against schema. Throws ex-info with :type ::invalid-args
and a human-readable :message on failure. Returns nil on success.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries