(batch-extract! filing-seq
output-dir
&
{:keys [items remove-tables? skip-existing?]
:or {remove-tables? false skip-existing? true}})Extract item sections from a seq of filings and write {accession-no}.edn to output-dir. Options: :items - set of item ids to extract (default: all) :remove-tables? - strip numeric tables (default: false) :skip-existing? - skip if output file already exists (default: true)
Extract item sections from a seq of filings and write {accession-no}.edn to output-dir.
Options:
:items - set of item ids to extract (default: all)
:remove-tables? - strip numeric tables (default: false)
:skip-existing? - skip if output file already exists (default: true)(extract-item filing item-id)Extract a single item section from a filing. Returns {:title "..." :text "..." :method ...} or nil.
Extract a single item section from a filing.
Returns {:title "..." :text "..." :method ...} or nil.(extract-items filing
&
{:keys [items remove-tables?] :or {remove-tables? false}})Extract item sections from a filing. Returns a map of item-id -> {:title "..." :text "..." :method ...}.
filing : filing metadata map (from edgar.filings/get-filings) Options: :items - set of item ids to extract e.g. #{"7" "1A"} (default: all) :remove-tables? - strip <table> elements before text extraction (default: false)
Example: (extract-items f :items #{"7" "1A"} :remove-tables? true) ;=> {"7" {:title "Management's Discussion..." :text "...20k chars..." ; :method :html-heading-boundaries} ; "1A" {:title "Risk Factors" :text "..." :method :html-heading-boundaries}}
Extract item sections from a filing.
Returns a map of item-id -> {:title "..." :text "..." :method ...}.
filing : filing metadata map (from edgar.filings/get-filings)
Options:
:items - set of item ids to extract e.g. #{"7" "1A"} (default: all)
:remove-tables? - strip <table> elements before text extraction (default: false)
Example:
(extract-items f :items #{"7" "1A"} :remove-tables? true)
;=> {"7" {:title "Management's Discussion..." :text "...20k chars..."
; :method :html-heading-boundaries}
; "1A" {:title "Risk Factors" :text "..." :method :html-heading-boundaries}}cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |