Malli schemas and validation helpers for the edgarjure public API.
Usage (in edgar.api): (schema/validate! ::filings-args {:ticker-or-cik toc :form form ...})
All public validate! calls throw ex-info with :type ::invalid-args on failure. The error message includes the human-readable Malli explanation.
Malli schemas and validation helpers for the edgarjure public API.
Usage (in edgar.api):
(schema/validate! ::filings-args {:ticker-or-cik toc :form form ...})
All public validate! calls throw ex-info with :type ::invalid-args on failure.
The error message includes the human-readable Malli explanation.(validate! schema args-map)Validate args-map against schema. Throws ex-info with :type ::invalid-args and a human-readable :message on failure. Returns nil on success.
Validate args-map against schema. Throws ex-info with :type ::invalid-args and a human-readable :message on failure. Returns nil on success.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |